import request from '@/utils/request'

export function monitorList(data) {
  return request({
    url: '/system/monitor/pageList',
    method: 'post',
    data
  })
}
// 获取监测系统名称
export function monitorNameList(data) {
    return request({
      url: '/system/monitor/list',
      method: 'get',
      data
    })
  }
//   详情查看
  export function monitorDetail(id) {
    return request({
      url: `/system/monitor/${id}`,
      method: 'get',
    })
  }
  //   新增
  export function toAddmonit(data) {
    return request({
      url: '/system/monitor/add',
      method: 'post',
      data
    })
  }
   //   生成密钥
   export function toGenerateKey(data) {
    return request({
      url: '/system/monitor/getSecret',
      method: 'get',
      data
    })
  }
     //   修改
     export function toUpdateMonitor(data) {
      return request({
        url: '/system/monitor/update',
        method: 'post',
        data
      })
    }
    //   删除
    export function toSliceMonitor(ids) {
      return request({
        url: `/system/monitor/delete/${ids}`,
        method: 'get',
      })
    }